@@ -201,9 +201,7 @@ class Contracted(Wrapper):
             "post": self._get_contracts_by_type("post"),
         }
         # TODO: write test for stack-like behavior (reverse "pre")
-        self._has_contracts = (
-            sum([len(l) for l in self.contract_functions.values()]) > 0
-        )
+        self._has_contracts = sum(len(l) for l in self.contract_functions.values()) > 0
 
     def __call__(self, *args, **kwargs):
         if self.implicit_hub:
@@ -227,6 +225,29 @@ class Contracted(Wrapper):
 
         return ret
 
+    def __getstate__(self):
+        return dict(
+            hub=self.hub,
+            ref=self.ref,
+            name=self.__name__,
+            implicit_hub=self.implicit_hub,
+            contracts=self.contracts,
+        )
+
+    def __setstate__(self, state):
+        hub = state["hub"]
+        ref = state["ref"]
+        name = state["name"]
+        func = hub[ref][name].func
+        self.__init__(
+            hub=hub,
+            func=func,
+            ref=ref,
+            name=name,
+            implicit_hub=state["implicit_hub"],
+            contracts=state["contracts"],
+        )
+
 
 class ContractedAsyncGen(Contracted):
     async def __call__(self, *args, **kwargs):
@@ -315,3 +336,39 @@ def create_contracted(
         return ContractedAsyncGen(hub, contracts, func, ref, name, implicit_hub)
     else:
         return Contracted(hub, contracts, func, ref, name, implicit_hub)
+
+
+class Partial:
+    """
+    A partial function that can be used for multiprocessing
+    """
+
+    def __init__(self, synchronous_function: Contracted, *args, **kwargs):
+        self.func = synchronous_function
+        self.args = args
+        self.kwargs = kwargs
+
+    def __call__(self):
+        ret = self.func(*self.args, **self.kwargs)
+        # We can't pickle a coroutine, so async functions need to finish here
+        # if this is executed in a forked process, we can't guarantee a loop exists
+        if asyncio.iscoroutine(ret):
+            loop = asyncio.new_event_loop()
+            try:
+                while asyncio.iscoroutine(ret):
+                    ret = loop.run_until_complete(ret)
+            finally:
+                loop.close()
+        return ret
+
+    def __getstate__(self):
+        return {
+            "func": self.func,
+            "args": self.args,
+            "kwargs": self.kwargs,
+        }
+
+    def __setstate__(self, state):
+        self.func = state["func"]
+        self.args = state["args"]
+        self.kwargs = state["kwargs"]
