@@ -321,9 +321,17 @@ def prep_loaded_mod(
     :param mod: A loader module
     :param mod_name: The name of the module to get from the loader
     :param contracts: Contracts functions to add to the sub
+    :param recursive_contracts:
     """
     lmod = this_sub._loaded.get(mod_name, LoadedMod(mod_name))
     ref = f"{this_sub._subname}.{mod_name}"  # getattr(hub, ref) should resolve to this module
+
+    # Recursively get the full reference to this mod
+    root = this_sub._root
+    while hasattr(root, "_subname"):
+        ref = f"{root._subname}.{ref}"
+        root = root._root
+
     sub_alias(this_sub, mod, mod_name)
 
     __func_alias__: Callable or Dict[str, str or Callable] = getattr(
