@@ -3,10 +3,15 @@ import collections.abc as abc
 import copy
 import inspect
 import logging
+import sys
+from typing import Any
+from typing import Dict
+from typing import Iterable
+from typing import Iterator
+from typing import List
+
 import pop.contract as contract
 import pop.hub
-import sys
-from typing import Any, Dict, Iterable, Iterator, List
 
 log = logging.getLogger(__name__)
 
