@@ -2,7 +2,6 @@
 The main interface for management of the aio loop
 """
 import asyncio
-import functools
 import signal
 from typing import Any
 from typing import AsyncGenerator
@@ -12,6 +11,7 @@ from typing import Iterable
 
 import proxy_tools
 
+import pop.contract
 import pop.hub
 
 __virtualname__ = "loop"
@@ -37,17 +37,14 @@ def create(hub, loop_plugin: str = None):
     if not hub.pop.loop.CURRENT_LOOP:
         hub.loop.init.create(loop_plugin)
 
-    if hub.pop.loop.FUT_QUE is None:
-        hub.pop.loop.FUT_QUE = asyncio.Queue(loop=hub.pop.Loop)
-
 
 def call_soon(hub: "pop.hub.Hub", ref: str, *args, **kwargs):
     """
     Schedule a coroutine to be called when the loop has time. This needs
     to be called after the creation of the loop
     """
-    fun = hub.pop.ref.get_func(ref)
-    hub.pop.Loop.call_soon(functools.partial(fun, *args, **kwargs))
+    coro = hub.pop.loop.wrap(hub[ref], *args, **kwargs)
+    return hub.pop.loop.CURRENT_LOOP.call_soon(hub.pop.loop.unwrap, coro)
 
 
 def ensure_future(hub: "pop.hub.Hub", ref: str, *args, **kwargs) -> asyncio.Future:
@@ -57,8 +54,12 @@ def ensure_future(hub: "pop.hub.Hub", ref: str, *args, **kwargs) -> asyncio.Futu
     the hold system to await the future when it is done making it easy
     to create a future that will be cleanly awaited in the background.
     """
-    fun = getattr(hub, ref)
-    future = asyncio.ensure_future(fun(*args, **kwargs), loop=hub.pop.Loop)
+    future = asyncio.ensure_future(hub[ref](*args, **kwargs))
+
+    if hub.pop.loop.FUT_QUE is None:
+        raise RuntimeError(
+            "Run 'await hub.pop.loop.init_futures()' to create the futures queue in the proper loop"
+        )
 
     def callback(fut):
         hub.pop.loop.FUT_QUE.put_nowait(fut)
@@ -67,6 +68,11 @@ def ensure_future(hub: "pop.hub.Hub", ref: str, *args, **kwargs) -> asyncio.Futu
     return future
 
 
+async def init_futures(hub):
+    if hub.pop.loop.FUT_QUE is None:
+        hub.pop.loop.FUT_QUE = asyncio.Queue()
+
+
 def start(
     hub: "pop.hub.Hub",
     *coros,
@@ -79,7 +85,7 @@ def start(
     Start a loop that will run until complete
     """
     hub.pop.loop.create(loop_plugin=loop_plugin)
-    loop: asyncio.AbstractEventLoop = hub.loop.init.get()
+    loop: asyncio.AbstractEventLoop = hub.pop.loop.CURRENT_LOOP
 
     if sigint:
         s = signal.SIGINT
@@ -94,7 +100,7 @@ def start(
     try:
         # DO NOT CHANGE THIS CALL TO run_forever! If we do that then the tracebacks
         # do not get resolved.
-        return loop.run_until_complete(asyncio.gather(*coros, loop=loop))
+        return loop.run_until_complete(asyncio.gather(*coros))
     except KeyboardInterrupt:
         print("Caught keyboard interrupt. Canceling...")
     finally:
@@ -106,6 +112,9 @@ async def _holder(hub):
     Just a sleeping while loop to hold the loop open while it runs until
     complete
     """
+    if hub.pop.loop.FUT_QUE is None:
+        hub.pop.loop.FUT_QUE = asyncio.Queue()
+
     while True:
         future = await hub.pop.loop.FUT_QUE.get()
         await future
@@ -117,6 +126,9 @@ async def await_futures(hub: "pop.hub.Hub"):
     This function is used to clean up futures when the loop is not opened
     up with hold=True so that ensured futures can be cleaned up on demand
     """
+    if hub.pop.loop.FUT_QUE is None:
+        hub.pop.loop.FUT_QUE = asyncio.Queue()
+
     while not hub.pop.loop.FUT_QUE.empty():
         future = await hub.pop.loop.FUT_QUE.get()
         await future
@@ -126,14 +138,15 @@ async def kill(hub: "pop.hub.Hub", wait: int or float = 0):
     """
     Close out the loop
     """
-    await asyncio.sleep(wait, loop=hub.pop.Loop)
-    hub.pop.Loop.stop()
+    await asyncio.sleep(wait)
+    hub.pop.loop.CURRENT_LOOP.stop()
     while True:
-        if not hub.pop.loop.CURRENT_LOOP.is_running():
-            hub.pop.loop.CURRENT_LOOP.close()
-            hub.pop.loop.CURRENT_LOOP = None
-
-        await asyncio.sleep(1, loop=hub.pop.Loop)
+        if hub.pop.loop.CURRENT_LOOP is not None:
+            if not hub.pop.loop.CURRENT_LOOP.is_running():
+                hub.pop.loop.CURRENT_LOOP.close()
+                hub.pop.loop.CURRENT_LOOP = None
+            else:
+                await asyncio.sleep(1)
 
 
 # Helpers for async operations
@@ -158,7 +171,7 @@ async def as_yielded(
             print(y)
     """
     fin = object()
-    que = asyncio.Queue(loop=hub.pop.Loop)
+    que = asyncio.Queue()
     to_clean = []
 
     async def _yield(agen: AsyncGenerator):
@@ -166,20 +179,20 @@ async def as_yielded(
             await que.put(comp)
 
     async def _ensure(coroutines: Iterable[Coroutine]):
-        for f in asyncio.as_completed(coroutines, loop=hub.pop.Loop):
+        for f in asyncio.as_completed(coroutines):
             await f
 
     async def _set_done():
         await que.put(fin)
 
     def _done(future: asyncio.Future):
-        to_clean.append(asyncio.ensure_future(_set_done(), loop=hub.pop.Loop))
+        to_clean.append(asyncio.ensure_future(_set_done()))
 
     coros = []
     for gen in gens:
         coros.append(_yield(gen))
 
-    fut = asyncio.ensure_future(_ensure(coros), loop=hub.pop.Loop)
+    fut = asyncio.ensure_future(_ensure(coros))
     fut.add_done_callback(_done)
 
     while True:
@@ -192,7 +205,7 @@ async def as_yielded(
 
 
 async def sleep(hub, delay: float, *args, **kwargs):
-    await asyncio.sleep(delay, loop=hub.pop.Loop, *args, **kwargs)
+    await asyncio.sleep(delay, *args, **kwargs)
 
 
 async def wrap(
@@ -207,9 +220,9 @@ async def wrap(
     :param hub:
     :param synchronous_function: The function to wrap
     """
-    return await hub.pop.Loop.run_in_executor(
+    return await hub.pop.loop.CURRENT_LOOP.run_in_executor(
         executor=hub.pop.loop.EXECUTOR,
-        func=functools.partial(synchronous_function, *args, **kwargs),
+        func=pop.contract.Partial(synchronous_function, *args, **kwargs),
     )
 
 
